# CheapClaw Fleet Console

统一控制台：全局配置、Bot 生命周期、状态监控、日志查看
自动刷新
Bot 总数
0
manifest bots
运行中
0
alive processes
待核销指令
0
pending instructions
控制台地址
-
-

## Fleet 配置

manifest_path
runtime_root
fleet_config_path
llm_config_path
http_proxy
https_proxy
all_proxy
user_history_compress_threshold_tokens
structured_call_info_compress_threshold_agents
structured_call_info_compress_threshold_tokens

## LLM 配置文件

llm_config_path

## Bot 列表与操作

bot_id | channel | enabled | alive | pid | pending | endpoint | 操作
--- | --- | --- | --- | --- | --- | --- | ---

## 新增 Bot

bot_id
display_name
channel
enabled
serve_webhooks
host
port
telegram.bot_token
allowed_chats(csv)
feishu.app_id
feishu.app_secret
feishu.mode
verify_token
encrypt_key
wa.access_token
wa.phone_number_id
wa.verify_token
wa.api_version
discord.bot_token
discord.intents
require_mention_in_guild
qq.onebot_api_base
qq.onebot_access_token
qq.onebot_post_secret
qq.onebot_self_id
require_mention_in_group
wechat.onebot_api_base
wechat.onebot_access_token
wechat.onebot_post_secret
wechat.onebot_self_id
require_mention_in_group
require_mention_in_group

## Bot 日志查看

bot_id
kind
lines

## 群聊 / 本地聊天（localweb）

新会话ID(可选)
会话名称
参与Bot(多选)
群里必须@
当前会话：-